===================
External references
===================

* I `presented reclass`__ at `LCA 2014`_, which as been recorded:

  * (Slides forthcoming)
  * `Video recording`__

__ http://linux.conf.au/schedule/30203/view_talk?day=wednesday
__ http://mirror.linux.org.au/pub/linux.conf.au/2014/Wednesday/59-Hierarchical_infrastructure_description_for_your_system_management_needs_-_Martin_Krafft.mp4

.. _LCA 2014: https://lca2014.linux.org.au

* I gave `a talk about reclass`__ at `DebConf13`_, which has been recorded:

  * `Slides`__
  * Video recording: `high quality (ogv)`__ | `high quality (webm)`__ | `low(er) quality (ogv)`__

__ http://penta.debconf.org/dc13_schedule/events/1048.en.html
__ http://annex.debconf.org/debconf-share/debconf13/slides/reclass.pdf
__ http://meetings-archive.debian.net/pub/debian-meetings/2013/debconf13/high/1048_Recursive_node_classification_for_system_automation.ogv
__ http://meetings-archive.debian.net/pub/debian-meetings/2013/debconf13/webm-high/1048_Recursive_node_classification_for_system_automation.webm
__ http://meetings-archive.debian.net/pub/debian-meetings/2013/debconf13/low/1048_Recursive_node_classification_for_system_automation.ogv

.. _DebConf13: http://debconf13.debconf.org

.. include:: substs.inc
